==> question2answer-1.5-language-lt.zip: lt/qa-lang-users.php <==
﻿<?php
	
/*
	Question2Answer (c) Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-users.php
	Version: See define()s at top of qa-include/qa-base.php
	Description: Language phrases for user management


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'about' => 'Apie',
		'add_user_x_favorites' => 'Pridėti vartotoją ^ į mano mėgstamiausius',
		'avatar_default' => 'Standartinis',
		'avatar_gravatar' => 'Rodyti mano ^1Gravatar^2 ikoną',
		'avatar_label' => 'Avataras:',
		'avatar_none' => 'Nėra',
		'block_user_button' => 'Blokuoti vartotoją',
		'blocked_users' => 'Blokuoti vartotojai',
		'change_email_link' => ' - ^1pakeisti el. paštą^2',
		'change_password' => 'Pakeisti slaptažodį',
		'confirm_complete' => 'Ačiū - jūsų el. pašto adresas buvo patvirtintas',
		'confirm_emailed' => 'Patvirtinimo nuoroda buvo išsiųsta jums. Paspauskite ant šios nuorodos, kad patvirtintumėte savo el. pašto adresą.',
		'confirm_required' => 'Tam kad pabaigtumėte registraciją, prašom paspausti ant patvirtinimo nuorodos kuri buvo jums išsiųsta, arba ^1paprašykite išsiųsti dar vieną^2.',
		'confirm_title' => 'El. pašto adreso patvirtinimas',
		'confirm_wrong_log_in' => 'Kodas neteisingas - prašom ^1prisijungti^2 ir išsiųsti naują nuorodą',
		'confirm_wrong_resend' => 'Kodas neteisingas - prašom paspausti žemiau tam, kad išsiųstumėte naują nuorodą',
		'delete_user_button' => 'Ištrinti vartotoją',
		'edit_user_button' => 'Redaguoti šį vartotoją',
		'email_confirmed' => 'Patvirtintas',
		'email_exists' => 'El. pašto adresas jau priklauso vienai iš paskirų',
		'email_handle_label' => 'El. pašto adresas arba vartotojo vardas:',
		'email_invalid' => 'El. pašto adresas yra nevalidus - prašom atidžiai patikrinti',
		'email_label' => 'El. pašto adresas:',
		'email_not_confirmed' => 'Dar nepatvirtintas',
		'email_please_confirm' => 'Prašom ^5patvirtinti^6',
		'email_required' => 'El. pašto adresas reikalaujamas - nebus rodomas viešai',
		'forgot_link' => 'Aš pamiršau savo slaptažodį',
		'full_name' => 'Pilnas vardas ir pavardė',
		'handle_empty' => 'Vartotojo vardas negali būti tuščias',
		'handle_exists' => 'Toks vartotojo vardas jau buvo registruotas - prašom pasirinkti kitokį',
		'handle_has_bad' => 'Vartotojo vardas negali turėti: ^',
		'handle_label' => 'Vartotojo vardas:',
		'hide_all_user_button' => 'Paslėpti visus šio vartotojo įrašus',
		'last_login_label' => 'Paskutinis prisijungimas:',
		'last_write_label' => 'Paskutinis įrašymo veiksmas:',
		'level_admin' => 'Administratorius',
		'level_editor' => 'Redaktorius',
		'level_expert' => 'Ekspertas',
		'level_moderator' => 'Moderatorius',
		'level_super' => 'Super Administratorius',
		'location' => 'Vieta',
		'log_in_to_access' => 'Dabar jūs galite ^1prisijungti^2 ir pasiekti savo paskyrą.',
		'login_button' => 'Prisijungti',
		'login_limit' => 'Perdaug bandymų prisijungti - prašom pabandyti už valandos',
		'login_title' => 'Prisijungimas',
		'mass_mailings_explanation' => 'Užsisakyti el. laiškus siunčiamus visiems vartotojams',
		'mass_mailings' => 'Masiniai el. laiškai:',
		'member_for' => 'Narystės trukmė:',
		'member_type' => 'Tipas:',
		'new_password_1' => 'Naujas slaptažodis:',
		'new_password_2' => 'Pakartokite slaptažodį:',
		'no_blocked_users' => 'Nerasta blokuotų vartotojų',
		'no_permission' => 'Jūs neturi teisių atlikti šią operaciją',
		'old_password' => 'Senas slaptažodis:',
		'only_shown_admins' => '(rodomas tik administratoriams)',
		'only_shown_moderators' => '(rodomas tik moderatoriams)',
		'password_changed' => 'Slaptažodis pakeistas',
		'password_label' => 'Slaptažodis:',
		'password_min' => 'Slaptažodis turi bent ^ simbolių ilgio',
		'password_mismatch' => 'Naujas slaptažodis buvo neteisingai pakartotas',
		'password_none' => 'Nėra. Tam kad prisijungti tiesiogiai, įveskite slatažodį žemiau.',
		'password_sent' => 'Jūsų naujas slaptažodis buvo išsiųstas jūsų el. paštu',
		'password_to_set' => 'Prašom nustatyti savo paskyros puslapyje',
		'password_wrong' => 'Slaptažodis neteisingas',
		'private_messages_explanation' => 'Leiskite vartotjams siųsti el. laiškus (neparodant mano el. pašto adreso)',
		'private_messages' => 'Privačios žinutės:',
		'profile_saved' => 'Profilis išsaugotas',
		'register_button' => 'Prisiregistruoti',
		'register_limit' => 'Gauta per daug registracijų - prašom pabandyti už valandos',
		'register_suspended' => 'Naujų vartotojų registracija buvo laikinai sustabdyta. Prašom pabandyti vėliau.',
		'register_title' => 'Prisiregistruoti nauju vartotoju',
		'registered_user' => 'Registruotas vartotojas',
		'remember_label' => 'Prisiminkite mane šiame kompiuteryje',
		'remove_avatar' => 'Pašalinti avatarą:',
		'reset_code_another' => 'išsiųsti dar kartą',
		'reset_code_emailed' => 'Jūsų kodas buvo išsiųstas el. paštu',
		'reset_code_label' => 'Kodas:',
		'reset_code_wrong' => 'Kodas neteisingas',
		'reset_title' => 'Atkurti užmirštą slaptažodį',
		'save_profile' => 'Išsaugoti profilį',
		'save_user' => 'Išsaugoti vartotoją',
		'send_confirm_button' => 'Išsiųsti patvirtinimo nuorodą',
		'send_password_button' => 'Išsiųsti naują slaptažodį',
		'send_reset_button' => 'Išsiųsti el. laišką slaptažodžio atstatymui',
		'send_reset_note' => 'Žinutė su instrukcijomis bus išsiųsta jūsų el. pašto adresu.',
		'special_users' => 'Ypatingi vartotojai',
		'unblock_user_button' => 'Atblokuoti vartotoją',
		'unsubscribe_complete' => 'Jūs atsisakėte masinio laiškų siuntimo iš ^0. Jūs galite juos vėl užsisakyti iš savo ^1paskyros^2 puslapio.', 
		'unsubscribe_title' => 'Atsisakyti',
		'unsubscribe_wrong_log_in' => 'Kodas neteisingas - prašom ^1prisijungti^2 tam, kad atsisakytumėte',
		'unsubscribe' => 'Atsisakyti:',
		'user_blocked' => '(blokuotas)',
		'user_not_found' => 'Vartotojas nerastas',
		'website' => 'Interneto svetainė',
		'x_ago_from_y' => 'prieš ^1 iš ^2',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/

==> question2answer-1.7-language-lt.zip: lt/qa-lang-users.php <==
﻿<?php
/*
	Question2Answer by Gideon Greenspan and contributors
	http://www.question2answer.org/

	File: qa-include/qa-lang-users.php
	Description: Language phrases for user management


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'about' => 'Apie',
		'add_user_x_favorites' => 'Pridėti vartotoją ^ į mano mėgstamiausius',
		'approve_required' => 'Prašome palaukti kol jūsų paskyra bus patvirtinga arba ^1įveskite papildomą informaciją^2.',
		'approve_title' => 'Laukiama vartotojo patvirtinimo',
		'approve_user_button' => 'Patvirtinti vartotoją',
		'approved_user' => 'Patvirtintas vartotojas',
		'avatar_default' => 'Standartinis',
		'avatar_gravatar' => 'Rodyti mano ^1Gravatar^2 ikoną',
		'avatar_label' => 'Avataras:',
		'avatar_none' => 'Nėra',
		'block_user_button' => 'Blokuoti vartotoją',
		'blocked_users' => 'Blokuoti vartotojai',
		'category_level_add' => ' - ^1pridėti teises priklausomai nuo kategorijos^2',
		'category_level_in' => 'kategorijai žemiau:',
		'category_level_label' => 'Pakelta iki:',
		'category_level_none' => 'Be pakėlimo',
		'change_email_link' => ' - ^1pakeisti el. paštą^2',
		'change_password' => 'Pakeisti slaptažodį',
		'confirm_complete' => 'Ačiū - jūsų el. pašto adresas buvo patvirtintas',
		'confirm_emailed' => 'Patvirtinimo nuoroda buvo išsiųsta jums. Paspauskite ant šios nuorodos, kad patvirtintumėte savo el. pašto adresą.',
		'confirm_required' => 'Tam kad pabaigtumėte registraciją, prašom paspausti ant patvirtinimo nuorodos kuri buvo jums išsiųsta, arba ^1paprašykite išsiųsti dar vieną^2.',
		'confirm_title' => 'El. pašto adreso patvirtinimas',
		'confirm_wrong_log_in' => 'Kodas neteisingas - prašom ^1prisijungti^2 ir išsiųsti naują nuorodą',
		'confirm_wrong_resend' => 'Kodas neteisingas - prašom paspausti žemiau tam, kad išsiųstumėte naują nuorodą',
		'delete_user_button' => 'Ištrinti vartotoją',
		'edit_profile' => 'Redaguoti mano profilį',
		'edit_user_button' => 'Redaguoti šį vartotoją',
		'email_confirmed' => 'Patvirtintas',
		'email_exists' => 'El. pašto adresas jau priklauso vienai iš paskirų',
		'email_handle_label' => 'El. pašto adresas arba vartotojo vardas:',
		'email_invalid' => 'El. pašto adresas yra nevalidus - prašom atidžiai patikrinti',
		'email_label' => 'El. pašto adresas:',
		'email_not_confirmed' => 'Dar nepatvirtintas',
		'email_please_confirm' => 'Prašom ^5patvirtinti^6',
		'email_required' => 'El. pašto adresas reikalaujamas - nebus rodomas viešai',
		'forgot_link' => 'Aš pamiršau savo slaptažodį',
		'full_name' => 'Pilnas vardas ir pavardė',
		'handle_empty' => 'Vartotojo vardas negali būti tuščias',
		'handle_exists' => 'Toks vartotojo vardas jau buvo registruotas - prašom pasirinkti kitokį',
		'handle_has_bad' => 'Vartotojo vardas negali turėti: ^',
		'handle_label' => 'Vartotojo vardas:',
		'hide_all_user_button' => 'Paslėpti visus šio vartotojo įrašus',
		'last_login_label' => 'Paskutinis prisijungimas:',
		'last_write_label' => 'Paskutinis įrašymo veiksmas:',
		'level_admin' => 'Administratorius',
		'level_editor' => 'Redaktorius',
		'level_expert' => 'Ekspertas',
		'level_for_category' => '^1 kategorijai ^2',
		'level_in_general' => 'bendrai',
		'level_moderator' => 'Moderatorius',
		'level_super' => 'Super Administratorius',
		'location' => 'Vieta',
		'log_in_to_access' => 'Dabar jūs galite ^1prisijungti^2 ir pasiekti savo paskyrą.',
		'login_button' => 'Prisijungti',
		'login_limit' => 'Perdaug bandymų prisijungti - prašom pabandyti už valandos',
		'login_title' => 'Prisijungimas',
		'mass_mailings' => 'Masiniai el. laiškai:',
		'mass_mailings_explanation' => 'Užsisakyti el. laiškus siunčiamus visiems vartotojams',
		'member_for' => 'Narystės trukmė:',
		'member_type' => 'Tipas:',
		'new_password_1' => 'Naujas slaptažodis:',
		'new_password_2' => 'Pakartokite slaptažodį:',
		'no_blocked_users' => 'Nerasta blokuotų vartotojų',
		'no_permission' => 'Jūs neturi teisių atlikti šią operaciją',
		'old_password' => 'Senas slaptažodis:',
		'only_shown_admins' => '(rodomas tik administratoriams)',
		'only_shown_editors' => '(rodomas tik redaguojantiems ir aukščiau)',
		'only_shown_experts' => '(rodomas tik ekspertams ir aukščiau)',
		'only_shown_moderators' => '(rodomas tik moderatoriams)',
		'password_changed' => 'Slaptažodis pakeistas',
		'password_label' => 'Slaptažodis:',
		'password_min' => 'Slaptažodis turi bent ^ simbolių ilgio',
		'password_mismatch' => 'Naujas slaptažodis buvo neteisingai pakartotas',
		'password_none' => 'Nėra. Tam kad prisijungti tiesiogiai, įveskite slatažodį žemiau.',
		'password_sent' => 'Jūsų naujas slaptažodis buvo išsiųstas jūsų el. paštu',
		'password_to_set' => 'Prašom nustatyti savo paskyros puslapyje',
		'password_wrong' => 'Slaptažodis neteisingas',
		'private_messages' => 'Privačios žinutės:',
		'private_messages_explanation' => 'Leiskite vartotjams siųsti el. laiškus (neparodant mano el. pašto adreso)',
		'profile_saved' => 'Profilis išsaugotas',
		'register_button' => 'Prisiregistruoti',
		'register_limit' => 'Gauta per daug registracijų - prašom pabandyti už valandos',
		'register_suspended' => 'Naujų vartotojų registracija buvo laikinai sustabdyta. Prašom pabandyti vėliau.',
		'register_title' => 'Prisiregistruoti nauju vartotoju',
		'registered_label' => 'Registruota:',
		'registered_user' => 'Registruotas vartotojas',
		'remember' => 'Prisiminti',
		'remember_label' => 'Prisiminkite mane šiame kompiuteryje',
		'remove_avatar' => 'Pašalinti avatarą:',
		'reset_code_another' => 'išsiųsti dar kartą',
		'reset_code_emailed' => 'Jūsų kodas buvo išsiųstas el. paštu',
		'reset_code_label' => 'Kodas:',
		'reset_code_wrong' => 'Kodas neteisingas',
		'reset_title' => 'Atkurti užmirštą slaptažodį',
		'save_profile' => 'Išsaugoti profilį',
		'save_user' => 'Išsaugoti vartotoją',
		'send_confirm_button' => 'Išsiųsti patvirtinimo nuorodą',
		'send_password_button' => 'Išsiųsti naują slaptažodį',
		'send_reset_button' => 'Išsiųsti el. laišką slaptažodžio atstatymui',
		'send_reset_note' => 'Žinutė su instrukcijomis bus išsiųsta jūsų el. pašto adresu.',
		'special_users' => 'Ypatingi vartotojai',
		'terms_not_accepted' => 'Jūs turite sutikti su Naudojimosi sąlygomis.',
		'unblock_user_button' => 'Atblokuoti vartotoją',
		'unsubscribe' => 'Atsisakyti:',
		'unsubscribe_complete' => 'Jūs atsisakėte masinio laiškų siuntimo iš ^0. Jūs galite juos vėl užsisakyti iš savo ^1paskyros^2 puslapio.', 
		'unsubscribe_title' => 'Atsisakyti',
		'unsubscribe_wrong_log_in' => 'Kodas neteisingas - prašom ^1prisijungti^2 tam, kad atsisakytumėte',
		'user_blocked' => '(blokuotas)',
		'user_not_found' => 'Vartotojas nerastas',
		'wall_posts' => 'Sienos įrašai:',
		'wall_posts_explanation' => 'Leisti vartotojams rašyti ant mano sienos (jums bus atsiųstas el. laiškas)',
		'website' => 'Interneto svetainė',
		'x_ago_from_y' => 'prieš ^1 iš ^2',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/
